/**
 * COPYRIGHT 2023 Flirc, Inc. All rights reserved.
 *
 * This copyright notice is Copyright Management Information under 17 USC 1202
 * and is included to protect this work and deter copyright infringement.
 * Removal or alteration of this Copyright Management Information without
 * the express written permission of Flirc, Inc. is prohibited, and any
 * such unauthorized removal or alteration will be a violation of federal law.
 *
 * @file
 * @brief   Library functions to perform CRC calculations.
 */

#include <stdint.h>

#ifndef _CRC_H
#define _CRC_H

/*
 * crc8_slow() calculates an 8-bit CRC over a range of bytes.
 *
 * @param [in]  buf  - pointer to buffer holding data.
 * @param [in]  len  - length of buffer.
 *
 * @return      CRC-8 value.
 */
uint8_t crc8_slower(const uint8_t *buf, size_t len);

/*
 * crc8_slower() calculates an 8-bit CRC over a range of bytes.
 *
 * @param [in]  buf  - pointer to buffer holding data.
 * @param [in]  len  - length of buffer.
 * @param [in]  len  - crc.
 *
 * @return      CRC-8 value.
 */
uint8_t crc8_slow(const uint8_t *data, uint32_t len, uint8_t crc);

/*
 * crc16_slow() calculates an 16-bit CRC over a range of bytes.
 *
 * @param [in]  buf  - pointer to buffer holding data.
 * @param [in]  len  - length of buffer.
 * @param [in]  len  - crc.
 *
 * @return      CRC-16 value.
 */
uint16_t crc16_slow(const uint8_t *data, uint32_t len, uint16_t crc);

/*
 * crc32_slow() calculates an 16-bit CRC over a range of bytes.
 *
 * @param [in]  buf  - pointer to buffer holding data.
 * @param [in]  len  - length of buffer.
 * @param [in]  len  - crc.
 *
 * @return      CRC-32 value.
 */
uint32_t crc32_slow(const uint8_t *data, uint32_t len, uint32_t crc);

/*
 * crc8() calculates an 8-bit CRC over a range of bytes.
 *
 * @param [in]  seed - Initial value to use (typically 0)
 * @param [in]  buf  - pointer to buffer holding data.
 * @param [in]  len  - length of buffer.
 *
 * @return      CRC-8 value.
 */
uint8_t crc8(uint8_t seed, const uint8_t *buf, size_t len);

/*
 * crc8pec() calculates an 8-bit CRC over a range of bytes.  The
 *           calculation is the same as what is used by SMBus PEC.
 *
 * @param [in]  seed - Initial value to use (typically 0)
 * @param [in]  buf  - pointer to buffer holding data.
 * @param [in]  len  - length of buffer.
 *
 * @return      CRC-8 value.
 */
uint8_t crc8pec(uint8_t seed, const uint8_t *buf, size_t len);

#endif
